==> evolution-1.4.5.zip: evolution-1.4.5/manager/includes/lang/errormsg/svenska-utf8.inc.php <==
<?php
/**
 * MODX error messages language file
 *
 * @version 1.0.13
 * @date 31/12/2013
 *
 * @language Swedish
 * @package modx
 * @subpackage manager
 *
 * Please commit your language changes on Transifex (https://www.transifex.com/projects/p/modx-evolution/) or on GitHub (https://github.com/modxcms/evolution).
 */
$_lang["No errors occured."] = "Inga fel inträffade.";
$_lang["An error occured!"] = "Ett fel inträffade!";
$_lang["You don't have enough privileges for this action!"] = "Du har inte tillräckliga rättigheter för den här aktionen!";
$_lang["ID passed in request is NaN!"] = "ID:t i anroppet är inte ett nummer!";
$_lang["The document is locked!"] = "Dokumentet är låst!";
$_lang["Too many results returned from database!"] = "Databasen returnerade för många resultat!";
$_lang["Not enough/ no results returned from database!"] = "Databasen returnerade inte tillräckligt många eller inga resultat alls!";
$_lang["Couldn't find parent document's name!"] = "Kunde inte hitta föräldradokumentets namn!";
$_lang["Logging error!"] = "Loggningsfel!";
$_lang["Table to optimise not found in request!"] = "Tabellen som ska optimeras finns inte i anropet!";
$_lang["No settings found in request!"] = "Inga inställningar kunde hittas i anropet!";
$_lang["The document must have a title!"] = "Dokumentet måste ha en titel!";
$_lang["No user selected as recipient of this message!"] = "Ingen användare vald som mottagare av detta meddelande!";
$_lang["No group selected as recipient of this message!"] = "Inga grupp vald som mottagare av detta meddelande!";
$_lang["The document was not found!"] = "Dokumentet kunde inte hittas!";
$_lang["Double action (GET & POST) posted!"] = "Dubbla aktioner i anropet (GET & POST)!";
$_lang["Document cannot be it's own parent!"] = "Ett dokument kan inte vara sin egen förälder!";
$_lang["Document's ID not passed in request!"] = "Dokumentets ID angavs inte i anropet!";
$_lang["New parent not set in request!"] = "Ingen ny förälder angavs i anropet!";
$_lang["don't know the user!" ] = "Felaktigt användarnamn eller lösenord angivet!";
$_lang["wrong password!"] = "Felaktigt användarnamn eller lösenord angivet!";
$_lang["Due to too many failed logins, you have been blocked!"] = "Du har blivit blockerad på grund av för många felaktiga inloggningsförsök!";
$_lang["You are blocked and cannot log in!"] = "Du är blockerad och kan inte logga in!";
$_lang["You are blocked and cannot log in! Please try again later."] = "Du är blockerad och kan inte logga in! Försök igen senare.";
$_lang["The security code you entered didn't validate! Please try to login again!"] = "Säkerhetskoden du angav var inte korrekt! Försök att logga in en gång till.";

==> evolution-1.4.36.zip: evolution-1.4.36/manager/includes/lang/errormsg/svenska-utf8.inc.php <==
<?php
/**
 * MODX error messages language file
 *
 * @version 1.0.13
 * @date 31/12/2013
 *
 * @language Swedish
 * @package modx
 * @subpackage manager
 *
 * Please commit your language changes on Transifex (https://www.transifex.com/projects/p/modx-evolution/) or on GitHub (https://github.com/modxcms/evolution).
 */
$_lang["No errors occured."] = "Inga fel inträffade.";
$_lang["An error occured!"] = "Ett fel inträffade!";
$_lang["You don't have enough privileges for this action!"] = "Du har inte tillräckliga rättigheter för den här aktionen!";
$_lang["ID passed in request is NaN!"] = "ID:t i anroppet är inte ett nummer!";
$_lang["The document is locked!"] = "Dokumentet är låst!";
$_lang["Too many results returned from database!"] = "Databasen returnerade för många resultat!";
$_lang["Not enough/ no results returned from database!"] = "Databasen returnerade inte tillräckligt många eller inga resultat alls!";
$_lang["Couldn't find parent document's name!"] = "Kunde inte hitta föräldradokumentets namn!";
$_lang["Logging error!"] = "Loggningsfel!";
$_lang["Table to optimise not found in request!"] = "Tabellen som ska optimeras finns inte i anropet!";
$_lang["No settings found in request!"] = "Inga inställningar kunde hittas i anropet!";
$_lang["The document must have a title!"] = "Dokumentet måste ha en titel!";
$_lang["No user selected as recipient of this message!"] = "Ingen användare vald som mottagare av detta meddelande!";
$_lang["No group selected as recipient of this message!"] = "Inga grupp vald som mottagare av detta meddelande!";
$_lang["The document was not found!"] = "Dokumentet kunde inte hittas!";
$_lang["Double action (GET & POST) posted!"] = "Dubbla aktioner i anropet (GET & POST)!";
$_lang["Document cannot be it's own parent!"] = "Ett dokument kan inte vara sin egen förälder!";
$_lang["Document's ID not passed in request!"] = "Dokumentets ID angavs inte i anropet!";
$_lang["New parent not set in request!"] = "Ingen ny förälder angavs i anropet!";
$_lang["don't know the user!" ] = "Felaktigt angivet användarnamn eller lösenord eller så har du blockerats!";
$_lang["wrong password!"] = "Felaktigt angivet användarnamn eller lösenord eller så har du blockerats!";
$_lang["Due to too many failed logins, you have been blocked!"] = "Felaktigt angivet användarnamn eller lösenord eller så har du blockerats!";
$_lang["You are blocked and cannot log in!"] = "Felaktigt angivet användarnamn eller lösenord eller så har du blockerats!";
$_lang["You are blocked and cannot log in! Please try again later."] = "Felaktigt angivet användarnamn eller lösenord eller så har du blockerats!";
$_lang["The security code you entered didn't validate! Please try to login again!"] = "Säkerhetskoden du angav var inte korrekt! Försök att logga in en gång till.";
